==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_entities/workorder_001/MultipleWorkOrderEquipment.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.workorderequipment_001.WorkOrderEquipment;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrderEquipment_001}WorkOrderEquipment" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workOrderEquipment"
})
@XmlRootElement(name = "MultipleWorkOrderEquipment")
public class MultipleWorkOrderEquipment {

    @XmlElement(name = "WorkOrderEquipment", namespace = "http://schemas.datastream.net/MP_entities/WorkOrderEquipment_001", required = true)
    protected List<WorkOrderEquipment> workOrderEquipment;

    /**
     * Gets the value of the workOrderEquipment property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the workOrderEquipment property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getWorkOrderEquipment().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link WorkOrderEquipment }
     * 
     * 
     */
    public List<WorkOrderEquipment> getWorkOrderEquipment() {
        if (workOrderEquipment == null) {
            workOrderEquipment = new ArrayList<WorkOrderEquipment>();
        }
        return this.workOrderEquipment;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_entities/workorder_001/MultipleWorkOrderEquipment.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.workorderequipment_001.WorkOrderEquipment;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrderEquipment_001}WorkOrderEquipment" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workOrderEquipment"
})
@XmlRootElement(name = "MultipleWorkOrderEquipment")
public class MultipleWorkOrderEquipment {

    @XmlElement(name = "WorkOrderEquipment", namespace = "http://schemas.datastream.net/MP_entities/WorkOrderEquipment_001", required = true)
    protected List<WorkOrderEquipment> workOrderEquipment;

    /**
     * Gets the value of the workOrderEquipment property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the workOrderEquipment property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getWorkOrderEquipment().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link WorkOrderEquipment }
     * 
     * 
     */
    public List<WorkOrderEquipment> getWorkOrderEquipment() {
        if (workOrderEquipment == null) {
            workOrderEquipment = new ArrayList<WorkOrderEquipment>();
        }
        return this.workOrderEquipment;
    }

}
